Index: /utils/CI/sette/all_functions.sh
===================================================================
--- /utils/CI/sette/all_functions.sh	(revision 13381)
+++ /utils/CI/sette/all_functions.sh	(revision 13382)
@@ -129,5 +129,5 @@
          # rsync keep preserve the modification time stamp.
          # To avoid case where a file in MY_SRC is replace by an older file, we touch the file
-         touch $lCFG/MY_SRC/*
+         touch --no-create $lCFG/MY_SRC/*
       fi
 
Index: /utils/CI/sette/input_ISOMIP+.cfg
===================================================================
--- /utils/CI/sette/input_ISOMIP+.cfg	(revision 13382)
+++ /utils/CI/sette/input_ISOMIP+.cfg	(revision 13382)
@@ -0,0 +1,1 @@
+ISOMIP+_v4.0.tar ISOMIP+_v4.0
Index: ils/CI/sette/input_SPITZ12.cfg
===================================================================
--- /utils/CI/sette/input_SPITZ12.cfg	(revision 13381)
+++ 	(revision )
@@ -1,1 +1,0 @@
-SPITZ12_v4.0.tar SPITZ12_v4.0
Index: /utils/CI/sette/input_WED025.cfg
===================================================================
--- /utils/CI/sette/input_WED025.cfg	(revision 13382)
+++ /utils/CI/sette/input_WED025.cfg	(revision 13382)
@@ -0,0 +1,1 @@
+WED025_v4.2.tar WED025_v4.2
Index: /utils/CI/sette/param.cfg
===================================================================
--- /utils/CI/sette/param.cfg	(revision 13381)
+++ /utils/CI/sette/param.cfg	(revision 13382)
@@ -74,5 +74,5 @@
 # LIST OF CONFIGURATIONS
 # to be updated if you added an new configuration in sette_test-cases.sh or sette_reference-configuration.sh
-TEST_CONFIGS=${SETTE_TEST_CONFIGS:-"ORCA2_ICE_PISCES ORCA2_OFF_PISCES AMM12 AGRIF SPITZ12 GYRE_PISCES SAS ORCA2_ICE_OBS ICE_AGRIF OVERFLOW LOCK_EXCHANGE VORTEX ISOMIP"}
+TEST_CONFIGS=${SETTE_TEST_CONFIGS:-"ORCA2_ICE_PISCES ORCA2_OFF_PISCES AMM12 AGRIF WED025 GYRE_PISCES SAS ORCA2_ICE_OBS ICE_AGRIF OVERFLOW LOCK_EXCHANGE VORTEX ISOMIP+"}
 # ------------------------------------------------------------------------------------------
 #
Index: /utils/CI/sette/sette_list_avail_cfg.sh
===================================================================
--- /utils/CI/sette/sette_list_avail_cfg.sh	(revision 13381)
+++ /utils/CI/sette/sette_list_avail_cfg.sh	(revision 13382)
@@ -9,5 +9,5 @@
 printf "%-15s \n" ORCA2_ICE_OBS
 printf "%-15s \n" AGRIF
-printf "%-15s \n" SPITZ12
+printf "%-15s \n" WED025
 echo ''
 echo 'Test cases available are named :'
@@ -16,4 +16,4 @@
 printf "%-15s \n" VORTEX
 printf "%-15s \n" ICE_AGRIF
-printf "%-15s \n" ISOMIP
+printf "%-15s \n" ISOMIP+
 echo ''
Index: /utils/CI/sette/sette_rpt.sh
===================================================================
--- /utils/CI/sette/sette_rpt.sh	(revision 13381)
+++ /utils/CI/sette/sette_rpt.sh	(revision 13382)
@@ -489,5 +489,5 @@
  echo ""
  echo "   !----restart----!   "
- for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WICE_AGRIF_ST 
+ for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WICE_AGRIF_ST 
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -497,5 +497,5 @@
  echo ""
  echo "   !----repro----!   "
- for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP_ST WVORTEX_ST WICE_AGRIF_ST
+ for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -524,5 +524,5 @@
      echo "REFERENCE directory : $NEMO_VALID_REF at rev $NEMO_REV_REF"
      echo ''
-     for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WISOMIP_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP_ST WVORTEX_ST WICE_AGRIF_ST
+     for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST
      do
        runcmpres $NEMO_VALID $repro_test $NEMO_VALID_REF $NEMO_REV_REF $pass
Index: /utils/CI/sette/sette_test-cases.sh
===================================================================
--- /utils/CI/sette/sette_test-cases.sh	(revision 13381)
+++ /utils/CI/sette/sette_test-cases.sh	(revision 13382)
@@ -150,5 +150,5 @@
 # VORTEX         : 
 # ICE_AGRIF      : 
-# ISOMIP         : 
+# ISOMIP+         : 
 # WAD
 
@@ -706,7 +706,7 @@
 
 # ------
-# ISOMIP
+# ISOMIP+
 # ------
-if [ ${config} == "ISOMIP" ] ;  then
+if [ ${config} == "ISOMIP+" ] ;  then
 ## Restartability tests
     export TEST_NAME="LONG"
@@ -716,9 +716,9 @@
     . ${SETTE_DIR}/all_functions.sh
     #
-    clean_config ISOMIP ISOMIP_ST 'tests'
-    #
-    sync_config  ISOMIP ISOMIP_ST 'tests'
-    #
-    . ./makenemo -m ${CMP_NAM} -n ISOMIP_ST -a ISOMIP -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
+    clean_config ISOMIP+ ISOMIP+_ST 'tests'
+    #
+    sync_config  ISOMIP+ ISOMIP+_ST 'tests'
+    #
+    . ./makenemo -m ${CMP_NAM} -n ISOMIP+_ST -a ISOMIP+ -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
     cd ${SETTE_DIR}
     . ./param.cfg
@@ -728,12 +728,12 @@
     clean_valid_dir
     JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=15
+    NPROC=27
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"ISOMIP_LONG\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 96
-    set_namelist namelist_cfg nn_stock 48
-    set_namelist namelist_cfg jpni 5
+    set_namelist namelist_cfg cn_exp \"ISOMIP+_LONG\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 1200
+    set_namelist namelist_cfg nn_stock 600
+    set_namelist namelist_cfg jpni 9
     set_namelist namelist_cfg jpnj 3
     set_namelist namelist_cfg sn_cfctl%l_runstat .true.
@@ -744,5 +744,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ISOMIP.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_ISOMIP+.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
 
     cd ${SETTE_DIR}
@@ -752,14 +752,14 @@
     clean_valid_dir
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"ISOMIP_SHORT\"
-    set_namelist namelist_cfg nn_it000 49
-    set_namelist namelist_cfg nn_itend 96
-    set_namelist namelist_cfg nn_stock 48
+    set_namelist namelist_cfg cn_exp \"ISOMIP+_SHORT\"
+    set_namelist namelist_cfg nn_it000 601
+    set_namelist namelist_cfg nn_itend 1200
+    set_namelist namelist_cfg nn_stock 600
     set_namelist namelist_cfg ln_rstart .true.
     set_namelist namelist_cfg nn_rstctl 2
-    set_namelist namelist_cfg jpni 5
+    set_namelist namelist_cfg jpni 9
     set_namelist namelist_cfg jpnj 3
     set_namelist namelist_cfg sn_cfctl%l_runstat .true.
-    set_namelist namelist_cfg cn_ocerst_in \"ISOMIP_LONG_00000048_restart\"
+    set_namelist namelist_cfg cn_ocerst_in \"ISOMIP+_LONG_00000600_restart\"
     if [ ${USING_MPMD} == "yes" ] ; then
        set_xio_using_server iodef.xml true
@@ -770,14 +770,14 @@
         L_NPROC=$(( $i - 1 ))
         L_NPROC=`printf "%04d\n" ${L_NPROC}`
-        ln -sf ../LONG/ISOMIP_LONG_00000048_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/ISOMIP+_LONG_00000600_restart_${L_NPROC}.nc .
     done
 
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ISOMIP.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_ISOMIP+.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
 
 ## Reproducibility tests
-    export TEST_NAME="REPRO_7_3"
+    export TEST_NAME="REPRO_9_3"
     cd ${MAIN_DIR}
     cd ${SETTE_DIR}
@@ -788,11 +788,11 @@
     clean_valid_dir
     JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=21
+    NPROC=27
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"ISOMIP_73\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 48
-    set_namelist namelist_cfg jpni 7
+    set_namelist namelist_cfg cn_exp \"ISOMIP+_93\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 600
+    set_namelist namelist_cfg jpni 9
     set_namelist namelist_cfg jpnj 3
     set_namelist namelist_cfg sn_cfctl%l_runstat .true.
@@ -803,5 +803,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ISOMIP.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_ISOMIP+.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -816,7 +816,7 @@
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"ISOMIP_84\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 48
+    set_namelist namelist_cfg cn_exp \"ISOMIP+_84\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 600
     set_namelist namelist_cfg jpni 8
     set_namelist namelist_cfg jpnj 4
@@ -828,5 +828,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_ISOMIP.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_ISOMIP+.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}

Index: /utils/CI/sette/sette_reference-configurations.sh
===================================================================
--- /utils/CI/sette/sette_reference-configurations.sh	(revision 13381)
+++ /utils/CI/sette/sette_reference-configurations.sh	(revision 13382)
@@ -150,5 +150,5 @@
 # AGRIF             : test AGRIF in a double zoom configuration in the nordic seas + 1 zoom in the eq. Pacific (AGRIF_DEMO)
 #                       and check that key_agrif without zoom = no key_agrif
 # SPITZ12           : regional configuration including sea-ice and tides (Spitzbergen)
 
 for config in ${TEST_CONFIGS}
@@ -1340,7 +1340,7 @@
 
 # -------
-# SPITZ12
+# WED025
 # -------
-if [ ${config} == "SPITZ12" ] ;  then
+if [ ${config} == "WED025" ] ;  then
 ## Restartability tests
     export TEST_NAME="LONG"
@@ -1349,23 +1349,23 @@
     # syncronisation if target directory/file exist (not done by makenemo)
     . ${SETTE_DIR}/all_functions.sh
-    sync_config  SPITZ12 SPITZ12_ST 'cfgs'
-    clean_config SPITZ12 SPITZ12_ST 'cfgs'
-    #
-    . ./makenemo -m ${CMP_NAM} -n SPITZ12_ST -r SPITZ12 -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
-    cd ${SETTE_DIR}
-    . ./param.cfg
-    . ./all_functions.sh
-    . ./prepare_exe_dir.sh
-    set_valid_dir
-    clean_valid_dir
-    JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=32
-    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
-    cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_LONG\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 240
-    set_namelist namelist_cfg nn_stock 120
-    set_namelist namelist_cfg nn_date0 20020101
+    sync_config  WED025 WED025_ST 'cfgs'
+    clean_config WED025 WED025_ST 'cfgs'
+    #
+    . ./makenemo -m ${CMP_NAM} -n WED025_ST -r WED025 -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
+    cd ${SETTE_DIR}
+    . ./param.cfg
+    . ./all_functions.sh
+    . ./prepare_exe_dir.sh
+    set_valid_dir
+    clean_valid_dir
+    JOB_FILE=${EXE_DIR}/run_job.sh
+    NPROC=32
+    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
+    cd ${EXE_DIR}
+    set_namelist namelist_cfg cn_exp \"WED025_LONG\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_stock 360
+    set_namelist namelist_cfg nn_date0 20000115
     set_namelist namelist_cfg jpni 4
     set_namelist namelist_cfg jpnj 8
@@ -1378,5 +1378,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     
     cd ${SETTE_DIR}
@@ -1386,8 +1386,8 @@
     clean_valid_dir
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_SHORT\"
-    set_namelist namelist_cfg nn_it000 121
-    set_namelist namelist_cfg nn_itend 240
-    set_namelist namelist_cfg nn_stock 120
+    set_namelist namelist_cfg cn_exp \"WED025_SHORT\"
+    set_namelist namelist_cfg nn_it000 361
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_stock 360
     set_namelist namelist_cfg ln_rstart .true.
     set_namelist namelist_cfg nn_rstctl 2
@@ -1395,11 +1395,11 @@
     set_namelist namelist_cfg jpnj 8
     set_namelist namelist_cfg sn_cfctl%l_runstat .true.
-    set_namelist namelist_cfg cn_ocerst_in \"S12_LONG_00000120_restart\"
-    set_namelist namelist_ice_cfg cn_icerst_in \"S12_LONG_00000120_restart_ice\"
+    set_namelist namelist_cfg cn_ocerst_in \"WED025_LONG_00000360_restart\"
+    set_namelist namelist_ice_cfg cn_icerst_in \"WED025_LONG_00000360_restart_ice\"
     for (( i=1; i<=$NPROC; i++)) ; do
         L_NPROC=$(( $i - 1 ))
         L_NPROC=`printf "%04d\n" ${L_NPROC}`
-        ln -sf ../LONG/S12_LONG_00000120_restart_${L_NPROC}.nc .
-        ln -sf ../LONG/S12_LONG_00000120_restart_ice_${L_NPROC}.nc .
+        ln -sf ../LONG/WED025_LONG_00000360_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/WED025_LONG_00000360_restart_ice_${L_NPROC}.nc .
     done
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1409,35 +1409,35 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
 
 ## Reproducibility tests
-    export TEST_NAME="REPRO_4_8"
-    cd ${MAIN_DIR}
-    cd ${SETTE_DIR}
-    . ./param.cfg
-    . ./all_functions.sh
-    . ./prepare_exe_dir.sh
-    set_valid_dir
-    clean_valid_dir
-    JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=32
-    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
-    cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_48\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 120
-    set_namelist namelist_cfg nn_date0 20020101
-    set_namelist namelist_cfg jpni 4
-    set_namelist namelist_cfg jpnj 8
-    set_namelist namelist_cfg sn_cfctl%l_runstat .true.
-    if [ ${USING_MPMD} == "yes" ] ; then
-       set_xio_using_server iodef.xml true
-    else
-       set_xio_using_server iodef.xml false
-    fi
-    cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    export TEST_NAME="REPRO_5_6"
+    cd ${MAIN_DIR}
+    cd ${SETTE_DIR}
+    . ./param.cfg
+    . ./all_functions.sh
+    . ./prepare_exe_dir.sh
+    set_valid_dir
+    clean_valid_dir
+    JOB_FILE=${EXE_DIR}/run_job.sh
+    NPROC=32
+    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
+    cd ${EXE_DIR}
+    set_namelist namelist_cfg cn_exp \"WED025_56\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_date0 20000115
+    set_namelist namelist_cfg jpni 6
+    set_namelist namelist_cfg jpnj 7
+    set_namelist namelist_cfg sn_cfctl%l_runstat .true.
+    if [ ${USING_MPMD} == "yes" ] ; then
+       set_xio_using_server iodef.xml true
+    else
+       set_xio_using_server iodef.xml false
+    fi
+    cd ${SETTE_DIR}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -1452,8 +1452,8 @@
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_84\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 120
-    set_namelist namelist_cfg nn_date0 20020101
+    set_namelist namelist_cfg cn_exp \"WED025_84\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_date0 20000115
     set_namelist namelist_cfg jpni 8
     set_namelist namelist_cfg jpnj 4
@@ -1465,5 +1465,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -150,5 +150,5 @@
 # AGRIF             : test AGRIF in a double zoom configuration in the nordic seas + 1 zoom in the eq. Pacific (AGRIF_DEMO)
 #                       and check that key_agrif without zoom = no key_agrif
-# SPITZ12           : regional configuration including sea-ice and tides (Spitzbergen)
+# WED025           : regional configuration including sea-ice and tides (Spitzbergen)
 
 for config in ${TEST_CONFIGS}